import java.text.*;
/**
 * @author Namita Singla
 * @version v1.0 Class representing customer object
 */
public class Customer {

	private final static int MAX_SIZE = 1000;

	private Rental[] rentals; // All rentals for this customer

	private int numRentals; // Number of rentals for this customer

	private String name;

	/**
	 * Constructor
	 * 
	 * @param name
	 *            name of customer
	 */
	public Customer(String name) {
		this.name = name;
		rentals = new Rental[MAX_SIZE];
	}

	/**
	 * Add rental for this customer
	 * 
	 * @param arg
	 *            Rental
	 */
	public void addRental(Rental arg) {
		if (numRentals >= MAX_SIZE) {
			System.err.println("Too many rentals.");
			return;
		}
		rentals[numRentals] = arg;
		numRentals++;
	}

	/**
	 * Get customer name
	 * 
	 * @return name of the customer
	 */
	public String getName() {
		return name;
	}

	/**
	 * Return statement for this customer
	 * 
	 * @return statement
	 */
	public String statement() {
		NumberFormat fmt = DecimalFormat.getCurrencyInstance();
		String result = "Rental record for " + getName() + "\n";
		for (int i = 0; i < numRentals; i++) {
			result += "\t" + rentals[i].getMovie().getTitle() + "\t"
					+ fmt.format(rentals[i].getCharge()) + "\n";
		}
		result += "Amount owed is " + fmt.format(getTotalCharge()) + "\n";
		result += "You earned " + getTotalFrequentRenterPoints()
				+ " frequent renter points";
		return result;
	}

	/**
	 * Get total charge for all rentals made by the customer
	 * 
	 * @return charge
	 */
	public double getTotalCharge() {
		double result = 0;
		for (int i = 0; i < numRentals; i++)
			result += rentals[i].getCharge();
		return result;
	}

	/**
	 * Get frequent renter points earned by this customer on all rentals
	 * 
	 * @return bonus points earned
	 */
	public int getTotalFrequentRenterPoints() {
		int result = 0;
		for (int i = 0; i < numRentals; i++)
			result += rentals[i].getFrequentRenterPoints();
		return result;
	}

	public static void main(String[] args) {
		Customer c = new Customer("Kent Beck");
		Movie r1 = new Movie("Usual Suspects", Movie.REGULAR);
		Movie r2 = new Movie("Silence of the Lambs", Movie.REGULAR);
		Movie c1 = new Movie("Shrek 2", Movie.CHILDREN);
		Movie c2 = new Movie("Harry Potter and the Prisoner of Azkaban",
				Movie.CHILDREN);
		Movie nr1 = new Movie("Grudge", Movie.NEW_RELEASE);
		Movie nr2 = new Movie("Ladder 49", Movie.NEW_RELEASE);
		c.addRental(new Rental(r1, 2));
		c.addRental(new Rental(r2, 2));
		c.addRental(new Rental(c1, 3));
		c.addRental(new Rental(c2, 3));
		c.addRental(new Rental(nr1, 2));
		c.addRental(new Rental(nr2, 3));
		System.out.println(c.statement());
	}
}