/**
 * @author Namita Singla
 * @version v1.0 Class representing movie object
 */
public class Movie {

	public static final int REGULAR = 0;

	public static final int NEW_RELEASE = 1;

	public static final int CHILDREN = 2;

	/**
	 * The title of this movie
	 */
	private String title;

	private Price price;

	/**
	 * Constructor
	 * 
	 * @param title
	 *            Title of this movie
	 * @param priceCode
	 *            Price code of this movie
	 */
	public Movie(String title, int priceCode) {
		this.title = title;
		setPriceCode(priceCode);
	}

	/**
	 * Get price code
	 * 
	 * @return price code
	 */
	public int getPriceCode() {
		return price.getPriceCode();
	}

	/**
	 * Set price code
	 * 
	 * @param priceCode
	 *            Price code to set for this movie
	 */
	public void setPriceCode(int priceCode) {
		switch (priceCode) {
		case Movie.REGULAR:
			price = new RegularPrice();
			break;
		case Movie.CHILDREN:
			price = new ChildrenPrice();
			break;		
		// YOUR CODE GOES HERE
		}
	}

	/**
	 * Get movie title
	 * 
	 * @return title
	 */
	public String getTitle() {
		return title;
	}

	/**
	 * Get charge for this movie
	 * 
	 * @param daysRented
	 *            number of days the movie is rented
	 * @return charge for this movie
	 */
	public double getCharge(int daysRented) {
		return price.getCharge(daysRented);
	}

	/**
	 * Get frequent renter points earned by renting this movie
	 * 
	 * @param daysRented
	 *            number of days the movie is rented
	 * @return frequent renter points
	 */
	public int getFrequentRenterPoints(int daysRented) {
		return price.getFrequentRenterPoints(daysRented);
	}
}